@@ -15,12 +15,12 @@ import org.rosuda.util.*;
 import org.rosuda.plugins.PluginManager;
 
 /** Common constants and gereral static methods for the entire application and ibase toolkit
-    @version $Id: Common.java,v 1.68 2006/08/18 21:02:40 urbaneks Exp $
+    @version $Id: Common.java,v 1.69 2006/08/29 18:29:16 urbaneks Exp $
 */
 public class Common
 {
     /** ibase version */
-    public static String Version="1.0-3";
+    public static String Version="1.0-4";
     /** ibase release */
     public static String Release="D729";
     /** application identifier (the first thing to do in main is to modify this) */
@@ -187,7 +187,7 @@ public class Common
     /** given mouse event this method determines whether zoom sequence was triggered (middle mouse button or META on a Mac) */ 
     public static boolean isZoomTrigger(MouseEvent ev) {
 		// warning: on a Mac buttons and modifiers are synthesized, see table above! 
-		System.out.println("isMac="+Platform.isMac+", "+ev);
+	// System.out.println("isMac="+Platform.isMac+", "+ev);
         return Platform.isMac?(
 		 (ev.getButton()==MouseEvent.BUTTON1 && ev.isMetaDown())   // Cmd+Button1 (any other Cmd combination is not valid!)
 		 || (ev.getButton()==MouseEvent.BUTTON2)                   // Button2
